# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.2] - 2026-02-16

### Added
- Add snyk import project models

### Fixed
- Fix uneeded pyproject.toml for doc

## [2.0.1] - 2026-02-10

### Added
- Add flags for delete, create, update, query

### Changed
- Bump version to v2.0.1 by @github-actions[bot]
- Linting
- Update readme
- Setup the snyk module

### Removed
- Remove circular dependency injenction

## New Contributors
* @github-actions[bot] made their first contribution
* @ made their first contribution
[2.0.2]: https://github.com/clearskies-py/snyk/compare/v2.0.1..v2.0.2

<!-- generated by git-cliff -->
